@@ -11,7 +11,6 @@
 use crate::{
     crypto::{self, Keypair, Verifier},
     error::Error,
-    messages::RoutingMsgUtils,
     network::NetworkUtils,
     peer::PeerUtils,
     section::{SectionPeersUtils, SectionUtils},
@@ -92,9 +91,9 @@ impl RelocateDetailsUtils for RelocateDetails {
         destination: XorName,
         age: u8,
     ) -> RelocateDetails {
-        let destination_key = *network
+        let destination_key = network
             .key_by_name(&destination)
-            .unwrap_or_else(|_| section.chain().root_key());
+            .unwrap_or_else(|_| *section.chain().root_key());
 
         RelocateDetails {
             pub_id: *peer.name(),
@@ -120,7 +119,7 @@ pub trait SignedRelocateDetailsUtils {
 
 impl SignedRelocateDetailsUtils for SignedRelocateDetails {
     fn new(signed_msg: RoutingMsg) -> Result<Self, Error> {
-        if let Variant::Relocate(_) = signed_msg.variant() {
+        if let Variant::Relocate(_) = signed_msg.variant {
             Ok(Self { signed_msg })
         } else {
             Err(Error::InvalidMessage)
@@ -128,8 +127,8 @@ impl SignedRelocateDetailsUtils for SignedRelocateDetails {
     }
 
     fn relocate_details(&self) -> Result<&RelocateDetails, Error> {
-        if let Variant::Relocate(details) = &self.signed_msg.variant() {
-            Ok(&details)
+        if let Variant::Relocate(details) = &self.signed_msg.variant {
+            Ok(details)
         } else {
             error!("SignedRelocateDetails does not contain Variant::Relocate");
             Err(Error::InvalidMessage)
@@ -281,7 +280,7 @@ mod tests {
     use proptest::prelude::*;
     use rand::{rngs::SmallRng, Rng, SeedableRng};
     use secured_linked_list::SecuredLinkedList;
-    use sn_messaging::node::SectionAuthorityProvider;
+    use sn_messaging::SectionAuthorityProvider;
     use xor_name::Prefix;
 
     #[test]
