@@ -192,6 +192,12 @@ impl Routing {
         self.dispatcher.clone().handle_commands(command).await
     }
 
+    /// Signals the Elders of our section to test connectivity to a node.
+    pub async fn start_connectivity_test(&self, name: XorName) -> Result<()> {
+        let command = Command::StartConnectivityTest(name);
+        self.dispatcher.clone().handle_commands(command).await
+    }
+
     /// Returns the current age of this node.
     pub async fn age(&self) -> u8 {
         self.dispatcher.core.read().await.node().age()
